From 1c9e266ae25f7f6067806d139e5971ce8513d2f6 Mon Sep 17 00:00:00 2001 From: tslil Date: Tue, 8 Sep 2026 11:55:28 +0100 Subject: ~25% speedup in selfplay due to: incremental zobrist hashing, smarter road checking, re-using the input computed for the NN --- include/nn.h | 2 ++ 1 file changed, 2 insertions(+) (limited to 'include/nn.h') diff --git a/include/nn.h b/include/nn.h index 9e576c1..871bd0f 100644 --- a/include/nn.h +++ b/include/nn.h @@ -35,6 +35,8 @@ void nn_prepare_head(float out_head[3], tak_state_p state); void nn_prepare_input(float *cur_board, tak_state_p state, const float embedding[NN_N_EMB]); + +int nn_last_cell_idxs(uint8_t *out, tak_state_p state); // =================================================================== // Network // =================================================================== -- cgit v1.3.1